Class: Google::Cloud::CertificateManager::V1::CertificateMapEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb

Overview

Defines a certificate map entry.

Defined Under Namespace

Modules: Matcher Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#certificates::Array<::String>

Returns A set of Certificates defines for the given hostname. There can be defined up to four certificates in each Certificate Map Entry. Each certificate must match pattern projects/*/locations/*/certificates/*.

Returns:

  • (::Array<::String>)

    A set of Certificates defines for the given hostname. There can be defined up to four certificates in each Certificate Map Entry. Each certificate must match pattern projects/*/locations/*/certificates/*.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The creation timestamp of a Certificate Map Entry.

Returns:



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#description::String

Returns One or more paragraphs of text description of a certificate map entry.

Returns:

  • (::String)

    One or more paragraphs of text description of a certificate map entry.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#hostname::String

Returns A Hostname (FQDN, e.g. example.com) or a wildcard hostname expression (*.example.com) for a set of hostnames with common suffix. Used as Server Name Indication (SNI) for selecting a proper certificate.

Note: The following fields are mutually exclusive: hostname, matcher. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    A Hostname (FQDN, e.g. example.com) or a wildcard hostname expression (*.example.com) for a set of hostnames with common suffix. Used as Server Name Indication (SNI) for selecting a proper certificate.

    Note: The following fields are mutually exclusive: hostname, matcher. If a field in that set is populated, all other fields in the set will automatically be cleared.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Set of labels associated with a Certificate Map Entry.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Set of labels associated with a Certificate Map Entry.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#matcher::Google::Cloud::CertificateManager::V1::CertificateMapEntry::Matcher

Returns A predefined matcher for particular cases, other than SNI selection.

Note: The following fields are mutually exclusive: matcher, hostname. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#name::String

Returns A user-defined name of the Certificate Map Entry. Certificate Map Entry names must be unique globally and match pattern projects/*/locations/*/certificateMaps/*/certificateMapEntries/*.

Returns:

  • (::String)

    A user-defined name of the Certificate Map Entry. Certificate Map Entry names must be unique globally and match pattern projects/*/locations/*/certificateMaps/*/certificateMapEntries/*.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#state::Google::Cloud::CertificateManager::V1::ServingState (readonly)

Returns Output only. A serving state of this Certificate Map Entry.

Returns:



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The update timestamp of a Certificate Map Entry.

Returns:



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
# File 'proto_docs/google/cloud/certificatemanager/v1/certificate_manager.rb', line 776

class CertificateMapEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines predefined cases other than SNI-hostname match when this
  # configuration should be applied.
  module Matcher
    # A matcher has't been recognized.
    MATCHER_UNSPECIFIED = 0

    # A primary certificate that is served when SNI wasn't specified in the
    # request or SNI couldn't be found in the map.
    PRIMARY = 1
  end
end